#
# spec file for package golang
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo


# MANUAL: Update the git_version and git_revision
%define git_version 7b2b1feb1de4817d522cc372af149ff48d25028e
%define git_short   7b2b1feb1de4
# How to get the git_revision
# git clone https://github.com/docker/libnetwork.git libnetwork
# cd libnetwork
# git checkout $git_version
# git_revision=r$(git rev-list HEAD | wc -l)
%define git_revision r2066

%global provider        github
%global provider_tld    com
%global project         docker
%global repo            libnetwork
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           golang-%{provider}-%{project}-%{repo}
# FIX-UPSTREAM: It looks like Docker _downgraded_ their version of libnetwork
#               in the bump from v17.07.0_ce (0.7.0+gitr2322_4a242dba7739) to
#               v17.10.0_ce (0.7.0+gitr2066_7b2b1feb1de4). This means that we
#               have to fake the version here to be different from the upstream
#               version. Please keep this in mind next time you do an update.
Version:        0.7.0.1+git%{git_revision}_%{git_short}
Release:        lp150.2.1
Summary:        Docker Networking
License:        Apache-2.0
Group:          Development/Languages/Golang
Url:            http://github.com/docker/libnetwork
Source0:        %{repo}-git.%{git_version}.tar.xz
Source1:        %{name}-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) = 1.8
ExcludeArch:    s390
%{go_provides}

%description
Libnetwork provides a native Go implementation for connecting containers

The goal of libnetwork is to deliver a robust Container Network Model that
provides a consistent programming interface and the required network
abstractions for applications.

%package -n docker-libnetwork
Summary:        Docker Networking
Group:          System/Management
AutoReqProv:    Off
Conflicts:      docker < 17.09.0_ce
Provides:       fix_bsc_1057743
# We provide a git revision so that Docker can require it properly.
Provides:       docker-libnetwork-git = %{git_version}

%description -n docker-libnetwork
The docker-proxy binary used by Docker that provides Docker with libnetwork
support.


%prep
%setup -q -n %{repo}-git.%{git_version}

%build
%goprep %{import_path}
export CGO_ENABLED=0
%gobuild -buildmode=default cmd/proxy

%install
%{goinstall}
mv %{buildroot}/%{_bindir}/proxy %{buildroot}/%{_bindir}/docker-proxy
%{gosrc}
%{gofilelist}

%fdupes %{buildroot}/%{_prefix}

%files -f file.lst
%defattr(-,root,root,-)
%doc README.md LICENSE MAINTAINERS

%files -n docker-libnetwork
%defattr(-,root,root,-)
%{_bindir}/docker-proxy

%changelog
* Thu Feb  1 2018 ro@suse.de
- do not build on s390, only on s390x (no go on s390)
* Mon Dec 11 2017 asarai@suse.com
- Update to version git.7b2b1feb1de4817d522cc372af149ff48d25028e (required by
  Docker v17.09.1_ce):
  * proxy: clean up code (addendum to #1598)
  * Use vndr for managing libnetwork dependencies
  * carry docker/docker #29564
  * Godep update for docker plugingetter pkg
  * return an error on overlay subnet is overlapped with hosts
  * Prioritize nw endpoint which can provide both v4 and v6 connectivity
  * proxy: fix an issue about half-closing net.TCPConn after io.Copy()
  * Add embedded DNS server support for host loopback resolver
  * Fix fqdn hostnames not added to /etc/hosts
* Wed Oct 18 2017 asarai@suse.com
- Update to version 0.7.0+git4a242dba7739 (required by Docker v17.07_ce):
  * optimize the rebroadcast for failure case
  * Revert "Fixes bug that mistook gw6 for gw."
  * Revert "Funnel peerAdd and peerDelete in a channel"
  * Avoid peerUpdate logic in swarm mode
  * Fixes bug which makes restoring endpoint mess
  * Revert "Avoid peerUpdate logic in swarm mode"
  * Funnel peerAdd and peerDelete in a channel
  * PeerInit for the sandbox init
  * PeerDbDelete was passing the wrong field
  * Lock goroutine to OS thread while changing NS
- Fix up _service file and versioning to actually be somewhat sane.
* Thu Sep 28 2017 thipp@suse.de
- always use -buildmode=default
* Wed Sep 27 2017 jmassaguerpla@suse.com
- fix bsc#1057743: this package provides the fix for this issue.
  I could not change the version of the libnetwork because that is
  attached to the upstream commits, and I can't control the release
  number, so I added this "symbol", fix_bsc_1057743 which is required
  by the latest docker package.
* Tue May  2 2017 jmassaguerpla@suse.com
- fix golang requirements
* Thu Apr 13 2017 opensuse-packaging@opensuse.org
- Update to version 0.0.0+git20170119.7b2b1fe:
  * Separate pool parsing from pool auto-allocation
  * Handle containers with different network drivers
  * Remove driver endpoints on network deleting
  * Update loadDriver to use pluginv2.
  * validate network and endpoint name more strictly
  * overlay driver support for Solaris Signed-off-by: Puneet Pruthi <puneetpruthi@gmail.com>
  * Updated vagrant box, ubuntu/vivid64 was remove from atlas.hasicorp.com
  * Use monotonic clock for reaping networkDB entries
  * Reap failed nodes after 24 hours
  * Do not update hosts file with internal networks endpoint IP
  * Fix issue for `--fixed-cidr` when bridge has multiple addresses
  * Add sandbox API for task insertion to service LB and service discovery
  * Enable ping for service vip address
  * Block non exposed port traffic on ingress nw interfaces
  * Fix some typos
  * Respect icc option for internal networks
  * fix nits in comments and log
  * Modify the serial number from 1 to 9
  * Allow concurrent calls to agentClose
  * Fixing incorrect resovler error message shown on daemon startup
  * Add NetworkDB API to fetch the per network peer (gossip cluster) list
  * Vendoring hcsshim to pick overlay changes
  * Windows overlay driver support
  * Change vxlan-id start-idx to 4096
  * If enabling ip forwarding set the default forward policy to drop
  * Register remote network driver on Windows.
  * update reapNode interval
  * remove unused mConfig
  * Check subnet overlap when programming of sandbox interface
  * Refactoring logrus import and formatting This fix tries to fix logrus formatting by removing `f` from `logrus.[Error|Warn|Debug|Fatal|Panic|Info]f` when formatting string is not present. Also fix import name to use original project name 'logrus' instead of 'log'
  * Default GW support for overlay networks
  * Support attachable in network.
  * Update libkv @1d84310
  * Respect auto allocation for --ipv6
  * Increase timeout for local store client
  * Add GetIDInRange API in idm package
  * IDM need not be bound by default vxlan-id start index
  * fix unsafe acces on arm
  * Fix new golint reported errors
  * Fix bug in DeleteNeighbor
  * Add a nil check for sandbox.osSbox
  * Update netlink @17ea11b
  * Set a timeout on the netlink handle sockets
  * Allow spaces in network names
  * Separate service LB & SD from network plumbing
  * Fix bug in needDefaultGW()
  * Revert "Enable ping for service vip address"
  * Add a ICMP reply rule for service VIP
  * Fix bug in link-local unmarshalling
  * Refactoring logrus import and formatting Fix import name to use original project name 'logrus' instead of 'log' Removing `f` from `logrus.Debugf` when formatting string is not present.
  * Serialize embedded resolver Start and Stop
  * Remove unnecessary string formats
  * Fix xtables_lock message probe
  * Control IPv6 on container's interface
  * Create vxlan-id space from 0 instead of starting from 1
  * Fixed misspelling
  * Fix a bug in idm.GetIDInRange()
  * Fix incorrect debug message
  * Add missing locks in agent and service code
  * networkdb: Properly format memberlist logs
  * fix review comments
  * Check for node's presence in networkDB's node map before accessing.
  * Correct regexp to match v6 addresses with zone ID
  * Fix fqdn hostnames not added to /etc/hosts
  * Handling the new experimental daemon flag
  * Handle the case of registering active plugins during remote init
  * Internal interface to differentiate built-in drivers from remote
  * drvregistry to allow overriding plugin
  * Defer PTR queries to external servers based on A/AAAA response
  * Add embedded DNS server support for host loopback resolver
  * proxy: fix an issue about half-closing net.TCPConn after io.Copy()
  * make network connect error message readable
  * fix nits in comments
  * fix typos
  * docs/remote.md: Remove unnecessary backquote
  * ResolveName should return copy of IPs
  * Prioritize nw endpoint which can provide both v4 and v6 connectivity
  * fix json
  * Updating Godeps to pull in plugingetter dependancy
  * Make use of GetAllManagedPluginsForCap to avoid loading v1-plugins
  * return an error on overlay subnet is overlapped with hosts
  * Godep update for docker plugingetter pkg
  * carry docker/docker #29564
  * Use vndr for managing libnetwork dependencies
  * proxy: clean up code (addendum to #1598)
* Thu Apr 13 2017 opensuse-packaging@opensuse.org
- Update to version 0.0.0+git20161019.0f53435:
  * fix race in serializing sandbox to string
  * Run API check to assert xfrm modules
  * Check for presence before installing forward rules
  * add Created to NetworkInfo
  * Avoid controller/service lock AB/BA situation
  * libnetwork support for Solaris Signed-off-by: Puneet Pruthi <puneetpruthi@gmail.com>
  * Fix map access race in populatedEndpoints
  * Do not use logrus for proxy
* Wed Apr 12 2017 jmassaguerpla@suse.com
- make sure we use go 1.7
* Mon Mar 13 2017 jmassaguerpla@suse.com
- rename lintrc to %%{name}-lintrc
* Fri Feb 24 2017 jmassaguerpla@suse.com
- add the docker-libnetwork package which installs docker-proxy
* Wed Feb 22 2017 thipp@suse.de
- Fix build
* Mon Feb 20 2017 jmassaguerpla@suse.com
- initial import
